.. torchtt documentation master file, created by
   sphinx-quickstart on Tue May 30 22:26:01 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.




.. image:: https://github.com/ion-g-ion/torchTT/blob/main/logo.png?raw=true
   :height: 100px
   :width: 200 px
   :alt: logo
   :align: center

.. include:: ./docs/intro_page.rst



:ref:`install-page-label`
------------------------

:ref:`about-tt-label`
---------------------

:ref:`reference-label`
----------------------

:ref:`index-label`
------------------


.. toctree::
   :hidden:
   :maxdepth: 2

   ./docs/intro_page.rst
   ./docs/install.rst
   ./docs/package-overview.rst
   ./docs/modules


